@@ -28,7 +28,6 @@ def root_dir():
     return os.path.dirname(".env.credentials")
 
 
-@pytest.fixture(scope="session", autouse=True)
 def add_root_dir_to_path(root_dir):
     path = os.path.abspath(os.path.join(os.path.dirname(__file__), root_dir))
     print(path)
@@ -37,7 +36,8 @@ def add_root_dir_to_path(root_dir):
 
 
 @pytest.fixture(scope="session", autouse=True)
-def copy_ini_to_root():
+def copy_ini_to_root(root_dir):
+    add_root_dir_to_path(root_dir)
     shutil.copy(os.path.join(os.path.dirname(__file__), "pytest.txt"),
                 os.path.abspath("pytest.ini"))
 
@@ -52,6 +52,7 @@ def module_name(pytestconfig):
 def connector_class(root_dir):
     """ This takes in the connector file name and tries to import it """
     try:
+        add_root_dir_to_path(root_dir)
         import src.connector as _conn
         return _conn
     except Exception:
